diff --git a/.travis.yml b/.travis.yml
index fb4c6ca1fd3ec7462be51a0f018ecbde1e9ff12d..709033c3a13b1a06073a76fd296ad05351592cf1 100644
--- a/.travis.yml
+++ b/.travis.yml
@@ -59,9 +59,9 @@ addons:
     - libexpat1
     - ninja-build
 
-notifications:
-  email:
-    recipients:
-      - support@nptool.org
-    on_success: change
-    on_failure: always
+#notifications:
+#  email:
+#    recipients:
+#      - support@nptool.org
+#    on_success: change
+#    on_failure: always
diff --git a/NPLib/scripts/test/basic.sh b/NPLib/scripts/test/basic.sh
index 12deffa930e06e78e8deae4fbe31cce69d09105c..d39579ba7894d859b4d6b702022ce255f41752fe 100755
--- a/NPLib/scripts/test/basic.sh
+++ b/NPLib/scripts/test/basic.sh
@@ -29,8 +29,8 @@ then
    cp $NPTOOL/NPData/Example1_Simu.root $NPTOOL/Outputs/Simulation/Example1.root
    # Run npanalysis
    npanalysis -R RunToTreat.txt -O Example1
-   # Run the ShowResult ROOT macro
-   echo ".q" | root -b -l ShowResult.C
+   # Run the ShowResults ROOT macro
+   echo ".q" | root -b -l ShowResults.C
 else
    # Case where reference simulation file does not exist
    echo "Warning!!! file $NPTOOL/NPData/Example1_Simu.root does not exist"
@@ -60,8 +60,8 @@ then
    cp $NPTOOL/NPData/Example2_Simu.root $NPTOOL/Outputs/Simulation/Example2.root
    # Run npanalysis
    npanalysis -R RunToTreat.txt -O Example2
-   # Run the ShowResult ROOT macro
-   echo ".q" | root -b -l ShowResult.C
+   # Run the ShowResults ROOT macro
+   echo ".q" | root -b -l ShowResults.C
 else
    # Case where reference simulation file does not exist
    echo "Warning!!! file $NPTOOL/NPData/Example1_Simu.root does not exist"